==> eve-api-client-1.6.2.tar.gz: eve-api-client-1.6.2/eveapi/esi/client.py <==
import logging
import re
from urllib.parse import quote

import redis
import requests
from django.conf import settings
from huey.api import TaskResultWrapper

from eveapi import huey

logger = logging.getLogger(__name__)
redis = redis.Redis(connection_pool=settings.REDIS_POOL)

base_url = 'https://esi.evetech.net'
oauth_url = 'https://login.eveonline.com/oauth'
token_url = 'https://login.eveonline.com/oauth/token'
authorize_url = 'https://login.eveonline.com/oauth/authorize'


class ESI:
    # for now, take refresh and access tokens as model objects
    def __init__(self, base=None, endpoint=None, headers=None, method=None, user_agent=None, version=None,
                 character=None, auth_callback=None):

        if headers is None:
            headers = {}  # apparently mutable datatype literals in function parameters are bad mkay

        if base:
            self._endpoint = endpoint or base._endpoint
            self._version = version or base._version
            self._datasource = base._datasource
            self._method = method or base._method
            self._headers = {**base._headers, **headers}
            self._character = character or base._character
            self._auth_callback = auth_callback or base._auth_callback

        else:
            self._endpoint = endpoint
            self._version = version or 'latest'
            self._datasource = 'tranquility'
            self._method = method or 'GET'
            self._character = character
            self._auth_callback = auth_callback
            self._headers = {
                'User-Agent': user_agent,
                'Accept': 'application/json',
                **headers,
            }

            if not user_agent:
                raise Exception('User agent required')

    def __str__(self):
        return '{} {}'.format(self._method, '/'.join([
            base_url,
            self._version,
            self._endpoint or '',  # endpoint may be None
        ]))

    def __getattr__(self, attr):
        """
        Adds to the esi path.

        If attr is an http method name, it will set the method attribute instead.
        Similarly, this sets the version.
        This allows you to reuse esi clients as a base for multiple routes that may need different methods or esi versions.

        Example:
            ```
            client = ESI(authtokens, etc.).v1.fleets[id]
            a = client.v2.members
            b = client.wings
            c = b.post()
            ```
        """
        if attr.startswith('_'):  # this gets called if you misspell an attribute
            logger.error('ESI attr {} starts with _, this should not happen'.format(attr))

        if attr == 'self' and self._character:  # replace self with auth character id
            attr = self._character

        elif attr in ['get', 'options', 'head', 'post', 'put', 'patch', 'delete']:  # set http method
            return ESI(self, method=attr.upper())

        elif re.match(r'(v\d+|latest|dev|legacy)', attr):  # set esi version instead of adding to the path
            return ESI(self, version=attr)

        url = self._endpoint + '/' + str(attr) if self._endpoint else str(attr)  # endpoint may be None
        return ESI(self, url)

    def __getitem__(self, key):
        return self.__getattr__(str(key))

    def __call__(self, value='', data=None, fetch_pages=False, cache=True, use_huey=True, blocking=True,
                 raise_error=False, **kwargs):
        url = '/'.join([
            base_url,
            self._version,
            self._endpoint or '',  # endpoint may be None
            quote(str(value))
        ])
        params = {key: quote(str(value_)) for key, value_ in kwargs.items()}

        # set auth header using auth_callback function
        headers = self._headers.copy()
        if self._character:
            auth = self._auth_callback(self._character)
            if isinstance(auth, TaskResultWrapper):
                auth = auth.get(blocking=True, timeout=90)

            headers['Authorization'] = auth

        kwargs = {
            'method': self._method,
            'url': url,
            'headers': headers,
            'params': params,
            'data': data,
            'fetch_pages': fetch_pages,
            'cache': cache,
            'raise_error': raise_error,
        }

        # run the esi call without huey, will default to huey on errors or multiple pages
        if not use_huey:
            return huey.esi.call_local(**kwargs)

        task = huey.esi(**kwargs)

        if blocking:
            logger.debug('waiting for ESI task response')
            # set a long timeout in case it hits max retries on long esi calls (max I've seen is 60 seconds)
            response = task.get(timeout=300, blocking=True)

            if raise_error and isinstance(response, requests.Response):
                response.raise_for_status()
            else:
                return response

        else:
            # if we're not blocking, return the task so we can make a bunch of calls,
            # then iterate through them to get(blocking) the results
            return task

    def _fork(self, **kwargs):
        return ESI(base=self, **kwargs)

==> eve-api-client-1.7.2.tar.gz: eve-api-client-1.7.2/eveapi/esi/client.py <==
import logging
import re
from urllib.parse import quote

import redis
import requests
from django.conf import settings
from huey.api import TaskResultWrapper

from eveapi import huey
from functools import partial

logger = logging.getLogger(__name__)
redis = redis.Redis(connection_pool=settings.REDIS_POOL)

base_url = 'https://esi.evetech.net'
oauth_url = 'https://login.eveonline.com/oauth'
token_url = 'https://login.eveonline.com/oauth/token'
authorize_url = 'https://login.eveonline.com/oauth/authorize'


class ESI:
    # for now, take refresh and access tokens as model objects
    def __init__(self, base=None, endpoint=None, headers=None, method=None, user_agent=None, version=None,
                 character=None, auth_callback=None):

        if headers is None:
            headers = {}  # apparently mutable datatype literals in function parameters are bad mkay

        if base:
            self._endpoint = endpoint or base._endpoint
            self._version = version or base._version
            self._datasource = base._datasource
            self._method = method or base._method
            self._headers = {**base._headers, **headers}
            self._character = character or base._character
            self._auth_callback = auth_callback or base._auth_callback

        else:
            self._endpoint = endpoint
            self._version = version or 'latest'
            self._datasource = 'tranquility'
            self._method = method or 'GET'
            self._character = character
            self._auth_callback = auth_callback
            self._headers = {
                'User-Agent': user_agent,
                'Accept': 'application/json',
                **headers,
            }

            if not user_agent:
                raise Exception('User agent required')

    def __str__(self):
        return '{} {}'.format(self._method, '/'.join([
            base_url,
            self._version,
            self._endpoint or '',  # endpoint may be None
        ]))

    def __getattr__(self, attr):
        """
        Adds to the esi path.

        If attr is an http method name, it will set the method attribute instead.
        Similarly, this sets the version.
        This allows you to reuse esi clients as a base for multiple routes that may need different methods or esi versions.

        Example:
            ```
            client = ESI(authtokens, etc.).v1.fleets[id]
            a = client.v2.members
            b = client.wings
            c = b.post()
            ```
        """
        if attr.startswith('_'):  # this gets called if you misspell an attribute
            logger.error('ESI attr {} starts with _, this should not happen'.format(attr))

        if attr == 'self' and self._character:  # replace self with auth character id
            attr = self._character

        elif attr in ['get', 'options', 'head', 'post', 'put', 'patch', 'delete']:  # set http method
            return ESI(self, method=attr.upper())

        elif re.match(r'(v\d+|latest|dev|legacy)', attr):  # set esi version instead of adding to the path
            return ESI(self, version=attr)

        url = self._endpoint + '/' + str(attr) if self._endpoint else str(attr)  # endpoint may be None
        return ESI(self, url)

    def __getitem__(self, key):
        return self.__getattr__(str(key))

    def __call__(self, value='', data=None, fetch_pages=False, cache=True, use_huey=True, blocking=True,
                 raise_error=False, **kwargs):
        url = '/'.join([
            base_url,
            self._version,
            self._endpoint or '',  # endpoint may be None
            quote(str(value))
        ])
        params = {key: quote(str(value_)) for key, value_ in kwargs.items()}

        # set auth header using auth_callback function
        headers = self._headers.copy()
        if self._character:
            headers['Authorization'] = get_auth_token(self._auth_callback, self._character)

        kwargs = {
            'method': self._method,
            'url': url,
            'headers': headers,
            'params': params,
            'data': data,
            'fetch_pages': fetch_pages,
            'cache': cache,
            'raise_error': raise_error,
            'auth_callback': partial(get_auth_token, self._auth_callback, self._character)
        }

        # run the esi call without huey, will default to huey on errors or multiple pages
        if not use_huey:
            return huey.esi.call_local(**kwargs)

        task = huey.esi(**kwargs)

        if blocking:
            logger.debug('waiting for ESI task response')
            # set a long timeout in case it hits max retries on long esi calls (max I've seen is 60 seconds)
            response = task.get(timeout=300, blocking=True)

            if raise_error and isinstance(response, requests.Response):
                response.raise_for_status()
            else:
                return response

        else:
            # if we're not blocking, return the task so we can make a bunch of calls,
            # then iterate through them to get(blocking) the results
            return task

    def _fork(self, **kwargs):
        return ESI(base=self, **kwargs)


def get_auth_token(auth_callback, character, force=False):
    auth = auth_callback(character, force=force)
    if isinstance(auth, TaskResultWrapper):
        auth = auth.get(blocking=True, timeout=90)

    return auth
